@@ -39,6 +39,7 @@ UNSUPPORTED_MEDIA_TYPE = 415
 REQUESTED_RANGE_NOT_SATISFIABLE = 416
 EXPECTATION_FAILED = 417
 IM_A_TEAPOT = 418
+UNPROCESSABLE_CONTENT = 422
 NO_RESPONSE = 444
 CLIENT_CLOSED_REQUEST = 499
 
@@ -95,6 +96,7 @@ RESPONSES = {
     REQUESTED_RANGE_NOT_SATISFIABLE: "Requested Range not satisfiable",
     EXPECTATION_FAILED: "Expectation Failed",
     IM_A_TEAPOT: "I'm a teapot",
+    UNPROCESSABLE_CONTENT: "Unprocessable Content",
     NO_RESPONSE: "No Response",
     CLIENT_CLOSED_REQUEST: "Client Closed Request",
     # 500
